@@ -1,6 +1,6 @@
 import functools
 from inspect import iscoroutinefunction
-from typing import Callable, TypeVar
+from typing import TypeVar
 
 _T = TypeVar("_T")
 
@@ -8,8 +8,8 @@ _T = TypeVar("_T")
 def securities_are_cached(func: _T) -> _T:
     @functools.wraps(func)
     async def predicate(self, *args, **kwargs):
-        if not self._securities_basic_cache:
-            await self._fetch_securities_cache()
+        if not self._securities_cache:
+            await self._fetch_securities()
         if iscoroutinefunction(func):
             return await func(self, *args, **kwargs)
         else:
